@@ -16,13 +16,43 @@
 # along with this program.  If not, see <http://www.gnu.org/licenses/>.
 
 
+from typing import Optional
+
 import httpx
 
+from pontos.github.api.client import GitHubAsyncREST
+
+
+class GitHubAsyncRESTContent(GitHubAsyncREST):
+    async def path_exists(
+        self, repo: str, path: str, *, branch: Optional[str] = None
+    ) -> bool:
+        """
+        Check if a path (file or directory) exists in a branch of a repository
+
+        Args:
+            repo: GitHub repository (owner/name) to use
+            path: to the file/directory in question
+            branch: Branch to check, defaults to default branch (:
+
+        Returns:
+            True if existing, False else
+        """
+        api = f"/repos/{repo}/contents/{path}"
+        params = {}
+        if branch:
+            params["ref"] = branch
+
+        response = await self._client.get(api, params=params)
+        return response.is_success
+
 
 class GitHubRESTContentMixin:
-    def path_exits(self, repo: str, path: str, branch: str = None) -> bool:
+    def path_exists(
+        self, repo: str, path: str, *, branch: Optional[str] = None
+    ) -> bool:
         """
-        Check if a path exists in a branch of a repository
+        Check if a path (file or directory) exists in a branch of a repository
 
         Args:
             repo: GitHub repository (owner/name) to use
