@@ -21,7 +21,8 @@ from typing import Dict, List, Optional, Union
 import httpx
 
 DEFAULT_GITHUB_API_URL = "https://api.github.com"
-DEFAULT_TIMEOUT_CONFIG = httpx.Timeout(180.0)  # three minutes
+DEFAULT_TIMEOUT = 180.0  # three minutes
+DEFAULT_TIMEOUT_CONFIG = httpx.Timeout(DEFAULT_TIMEOUT)  # three minutes
 JSON_OBJECT = Dict[str, Union[str, bool, int]]  # pylint: disable=invalid-name
 JSON = Union[List[JSON_OBJECT], JSON_OBJECT]
 
@@ -33,32 +34,6 @@ class FileStatus(Enum):
     RENAMED = "renamed"
 
 
-class RepositoryType(Enum):
-    ALL = "all"
-    PUBLIC = "public"
-    PRIVATE = "private"
-    FORKS = "forks"
-    SOURCES = "sources"
-    MEMBER = "member"
-    INTERNAL = "internal"
-
-
-class WorkflowRunStatus(Enum):
-    ACTION_REQUIRED = "action_required"
-    CANCELLED = "cancelled"
-    COMPLETED = "completed"
-    FAILURE = "failure"
-    IN_PROGRESS = "in_progress"
-    NEUTRAL = "neutral"
-    QUEUED = "queued"
-    REQUESTED = "requested"
-    SKIPPED = "skipped"
-    STALE = "stale"
-    SUCCESS = "success"
-    TIMED_OUT = "timed_out"
-    WAITING = "waiting"
-
-
 def _get_next_url(response: httpx.Response) -> Optional[str]:
     if response and response.links:
         try:
