@@ -17,8 +17,7 @@
 
 
 import re
-from pathlib import Path
-from typing import Generator, Tuple
+from typing import Generator, Optional, Tuple
 
 from packaging.version import Version
 
@@ -29,54 +28,37 @@ from .helper import (
     safe_version,
     versions_equal,
 )
-from .version import VersionCommand
+from .version import UpdatedVersion, VersionCommand
 
 
 class CMakeVersionCommand(VersionCommand):
-    project_file_path = None
-
-    def __init__(self, *, project_file_path: Path = None):
-        if not project_file_path:
-            project_file_path = Path.cwd() / "CMakeLists.txt"
-        if not project_file_path.exists():
-            raise VersionError(f"{str(project_file_path)} file not found.")
-
-        super().__init__(
-            project_file_path=project_file_path,
-        )
+    project_file_name = "CMakeLists.txt"
 
     def update_version(
         self, new_version: str, *, develop: bool = False, force: bool = False
-    ):
+    ) -> UpdatedVersion:
         content = self.project_file_path.read_text(encoding="utf-8")
         cmvp = CMakeVersionParser(content)
         previous_version = self.get_current_version()
 
         if not force and versions_equal(new_version, previous_version):
-            self._print("Version is already up-to-date.")
-            return
+            return UpdatedVersion(previous=previous_version, new=new_version)
 
         new_content = cmvp.update_version(new_version, develop=develop)
         self.project_file_path.write_text(new_content, encoding="utf-8")
-        self._print(f"Updated version from {previous_version} to {new_version}")
-
-    def print_current_version(self):
-        self._print(self.get_current_version())
+        return UpdatedVersion(previous=previous_version, new=new_version)
 
     def get_current_version(self) -> str:
         content = self.project_file_path.read_text(encoding="utf-8")
         return CMakeVersionParser(content).get_current_version()
 
-    def verify_version(self, version: str):
+    def verify_version(self, version: str) -> None:
         current_version = self.get_current_version()
         if not is_version_pep440_compliant(current_version):
             raise VersionError(
                 f"The version {current_version} is not PEP 440 compliant."
             )
 
-        if versions_equal(self.get_current_version(), version):
-            self._print("OK")
-
 
 class CMakeVersionParser:
     def __init__(self, cmake_content_lines: str):
@@ -89,7 +71,7 @@ class CMakeVersionParser:
         self._project_dev_version_line_number = pd_line_no
         self._project_dev_version = pd
 
-    __cmake_scanner = re.Scanner(
+    __cmake_scanner = re.Scanner(  # type: ignore
         [
             (r"#.*", lambda _, token: ("comment", token)),
             (r'"[^"]*"', lambda _, token: ("string", token)),
@@ -142,18 +124,20 @@ class CMakeVersionParser:
 
         return "\n".join(self._cmake_content_lines)
 
-    def _find_version_in_cmake(self, content: str) -> Tuple[int, str]:
+    def _find_version_in_cmake(
+        self, content: str
+    ) -> Tuple[int, str, Optional[int], Optional[str]]:
         in_project = False
         in_version = False
 
-        version_line_no: int = None
-        version: str = None
+        version_line_no: Optional[int] = None
+        version: Optional[str] = None
 
         in_set = False
         in_project_dev_version = False
 
-        project_dev_version_line_no: int = None
-        project_dev_version: int = None
+        project_dev_version_line_no: Optional[int] = None
+        project_dev_version: Optional[str] = None
 
         for lineno, token_type, value in self._tokenize(content):
             if token_type == "word" and value == "project":
@@ -202,7 +186,7 @@ class CMakeVersionParser:
             else False
         )
 
-    def _tokenize(
+    def _tokenize(  # type: ignore
         self, content: str
     ) -> Generator[
         Tuple[int, str, str],
