@@ -16,9 +16,9 @@
 # You should have received a copy of the GNU General Public License
 # along with this program.  If not, see <http://www.gnu.org/licenses/>.
 
+import unittest
 from datetime import date
 from pathlib import Path
-import unittest
 
 from pontos import changelog
 
@@ -27,20 +27,20 @@ class ChangelogUpdateTestCase(unittest.TestCase):
     def test_markdown_based_on_example(self):
         own_path = Path(__file__).absolute()
         test_directory = own_path.__str__()[0 : (len(own_path.name) * -1)]
-        path = test_directory + 'unreleased_changelog_example.md'
+        path = test_directory + "unreleased_changelog_example.md"
         expeced_changelog = Path(
-            test_directory + 'expected_changelog.md'
-        ).read_text(encoding='utf-8')
+            test_directory + "expected_changelog.md"
+        ).read_text(encoding="utf-8")
         expeced_release_notes = Path(
-            test_directory + 'expected_release_notes.md'
-        ).read_text(encoding='utf-8')
+            test_directory + "expected_release_notes.md"
+        ).read_text(encoding="utf-8")
         expeced_changelog = expeced_changelog.format(date.today().isoformat())
         expeced_release_notes = expeced_release_notes.format(
             date.today().isoformat()
         )
 
-        test_md = Path(path).read_text(encoding='utf-8')
-        updated, release_notes = changelog.update(test_md, '1.2.3', 'hidden')
+        test_md = Path(path).read_text(encoding="utf-8")
+        updated, release_notes = changelog.update(test_md, "1.2.3", "hidden")
         self.assertEqual(expeced_changelog, updated)
         self.assertEqual(expeced_release_notes, release_notes)
 
@@ -55,9 +55,9 @@ something, somehing
 - cool stuff 1
 - cool stuff 2
 """
-        updated, release_notes = changelog.update(test_md, '1.2.3', 'hidden')
-        self.assertIs('', updated)
-        self.assertIs('', release_notes)
+        updated, release_notes = changelog.update(test_md, "1.2.3", "hidden")
+        self.assertIs("", updated)
+        self.assertIs("", release_notes)
 
     def test_update_markdown_return_changelog_when_only_unreleased(self):
         released = f"""
@@ -83,7 +83,7 @@ I don't recognize it anymore
 
         test_md = unreleased
         released_md = released
-        updated, release_notes = changelog.update(test_md, '1.2.3')
+        updated, release_notes = changelog.update(test_md, "1.2.3")
         self.assertEqual(released_md.strip(), updated.strip())
         self.assertEqual(released.strip(), release_notes.strip())
 
@@ -144,10 +144,8 @@ I don't recognize it anymore
 
         test_md = unreleased
         updated, release_notes = changelog.update(
-            test_md, '1.2.3', containing_version='1.2.3'
+            test_md, "1.2.3", containing_version="1.2.3"
         )
-        print(updated)
-        print(release_notes)
         self.assertEqual(released_md.strip(), updated.strip())
         self.assertEqual(released.strip(), release_notes.strip())
 
@@ -184,7 +182,7 @@ something, somehing
 - cool stuff 2"""
         test_md = test_md_template.format(unreleased)
         released_md = test_md_template.format(released)
-        updated, release_notes = changelog.update(test_md, '1.2.3')
+        updated, release_notes = changelog.update(test_md, "1.2.3")
         self.assertEqual(released_md.strip(), updated.strip())
         self.assertEqual(released.strip(), release_notes.strip())
 
@@ -223,7 +221,7 @@ something, somehing
 - cool stuff 2"""
         test_md = test_md_template.format(unreleased)
         released_md = test_md_template.format(released)
-        updated, release_notes = changelog.update(test_md, '1.2.3')
+        updated, release_notes = changelog.update(test_md, "1.2.3")
         self.assertEqual(released_md.strip(), updated.strip())
         self.assertEqual(released.strip(), release_notes.strip())
 
@@ -263,5 +261,5 @@ something, somehing
         released_md = test_md_template.format(
             keep_a_changelog_skeleton + released
         )
-        updated = changelog.add_skeleton(test_md, '1.2.3', 'hidden')
+        updated = changelog.add_skeleton(test_md, "1.2.3", "hidden")
         self.assertEqual(released_md.strip(), updated.strip())
