@@ -22,12 +22,14 @@ import unittest
 from argparse import Namespace
 from contextlib import redirect_stderr
 from pathlib import Path
-from unittest.mock import Mock
+from unittest.mock import Mock, patch
 
 from pontos.github.api import FileStatus
 from pontos.github.argparser import parse_args
 from pontos.github.cmds import (
     create_pull_request,
+    create_release,
+    create_tag,
     file_status,
     update_pull_request,
 )
@@ -46,8 +48,8 @@ class TestArgparsing(unittest.TestCase):
             "main",
             "baz in main",
         ]
-
-        parsed_args = parse_args(argv)
+        with patch.dict("os.environ", {}, clear=True):
+            parsed_args = parse_args(argv)
 
         template = Path().cwd() / "pontos/github/pr_template.md"
 
@@ -82,7 +84,8 @@ class TestArgparsing(unittest.TestCase):
             "baz in main",
         ]
 
-        parsed_args = parse_args(argv)
+        with patch.dict("os.environ", {}, clear=True):
+            parsed_args = parse_args(argv)
 
         self.assertEqual(parsed_args.command, "pr")
         self.assertEqual(parsed_args.token, "GITHUB_TOKEN")
@@ -110,7 +113,9 @@ class TestArgparsing(unittest.TestCase):
             "some.file",
         ]
 
-        parsed_args = parse_args(argv)
+        with patch.dict("os.environ", {}, clear=True):
+            parsed_args = parse_args(argv)
+
         output = io.open(Path("some.file"), mode="w", encoding="utf-8")
 
         expected_args = Namespace(
@@ -133,3 +138,50 @@ class TestArgparsing(unittest.TestCase):
 
         output.close()
         parsed_args.output.close()
+
+    def test_create_release_parse_args(self):
+        argv = [
+            "re",
+            "create",
+            "foo/bar",
+            "123",
+            "release_name",
+            "--body",
+            "foo",
+        ]
+
+        with patch.dict("os.environ", {}, clear=True):
+            parsed_args = parse_args(argv)
+
+        self.assertEqual(parsed_args.command, "re")
+        self.assertEqual(parsed_args.token, "GITHUB_TOKEN")
+        self.assertEqual(parsed_args.re_func, create_release)
+        self.assertEqual(parsed_args.repo, "foo/bar")
+        self.assertEqual(parsed_args.tag, "123")
+        self.assertEqual(parsed_args.name, "release_name")
+        self.assertEqual(parsed_args.body, "foo")
+        self.assertEqual(parsed_args.target_commitish, None)
+        self.assertFalse(parsed_args.draft)
+        self.assertFalse(parsed_args.prerelease)
+
+    def test_create_tag_parse_args(self):
+        argv = [
+            "tag",
+            "create",
+            "foo/bar",
+            "v1",
+            "test user",
+            "",
+            "sha",
+            "test@test.test",
+        ]
+
+        parsed_args = parse_args(argv)
+
+        self.assertEqual(parsed_args.command, "tag")
+        self.assertEqual(parsed_args.tag_func, create_tag)
+        self.assertEqual(parsed_args.repo, "foo/bar")
+        self.assertEqual(parsed_args.tag, "v1")
+        self.assertEqual(parsed_args.message, "")
+        self.assertEqual(parsed_args.git_object, "sha")
+        self.assertEqual(parsed_args.email, "test@test.test")
